/*
 * A file accessor employing a file provided by an Ext2-compatible filesystem.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <ext2fs/ext2fs.h>

#include <fsserver/accessor.h>
#include <fsserver/ext2_file_operations.h>



/* An Ext2 file accessor, providing flexpages corresponding to file regions. */

class Ext2FileAccessor : public Accessor
{
protected:
    Ext2FileOperations *_ops;
    ext2_file_t _file;

    /* Data transfer helper methods. */

    virtual void fill_populated(Flexpage *flexpage);

    virtual void flush_populated(Flexpage *flexpage);

public:
    explicit Ext2FileAccessor(Ext2FileOperations *ops, ext2_file_t file,
                              fileid_t fileid);

    virtual void close();

    virtual offset_t get_size();

    virtual void set_size(offset_t size);

    virtual void remove();
};

// vim: tabstop=4 expandtab shiftwidth=4
